@@ -10,7 +10,7 @@ import html
 from collections import namedtuple, OrderedDict
 import math
 
-__version__ = '0.18.0'
+__version__ = '0.18.1'
 __author__ = 'Danny Lin'
 __author_email__ = 'danny0838@gmail.com'
 __homepage__ = 'https://github.com/danny0838/sts-lib'
@@ -365,8 +365,8 @@ class StsDict():
         """
         stsdicts = [self.__class__().load(*files) for files in filegroups]
         newstsdict = self
-        while len(stsdicts):
-            newstsdict = newstsdict.join(stsdicts.pop(0))
+        for stsdict in stsdicts:
+            newstsdict = newstsdict.join(stsdict)
         return newstsdict
 
     def join(self, stsdict):
@@ -526,15 +526,15 @@ class StsDict():
         text = parts
         parts = self._split(parts)
 
-        queue = [(parts, 0, 0)]
-        subqueue = []
+        stack = [(parts, 0, 0)]
+        substack = []
         results = OrderedDict()
-        while len(queue):
-            (parts, matched, nextindex) = data = queue.pop()
+        while len(stack):
+            (parts, matched, nextindex) = data = stack.pop()
             if nextindex < len(parts):
-                self._apply_enum_sub(subqueue, data, include_short=include_short, include_self=include_self)
-                while len(subqueue):
-                    queue.append(subqueue.pop())
+                self._apply_enum_sub(substack, data, include_short=include_short, include_self=include_self)
+                while len(substack):
+                    stack.append(substack.pop())
             elif matched > 0:
                 results["".join(parts)] = True
 
@@ -545,7 +545,7 @@ class StsDict():
 
         return results
 
-    def _apply_enum_sub(self, queue, data, include_short=False, include_self=False):
+    def _apply_enum_sub(self, stack, data, include_short=False, include_self=False):
         """Helper function of apply_enum
         """
         (parts, matched, index) = data
@@ -553,7 +553,7 @@ class StsDict():
 
         # add atomic stepping if no match
         if match is None:
-            queue.append((parts, matched, index + 1))
+            stack.append((parts, matched, index + 1))
             return
 
         has_atomic_match = False
@@ -565,7 +565,7 @@ class StsDict():
                 match.conv.values.append(match_key)
         for value in match.conv.values:
             result = parts[:index] + [value] + parts[match.end:]
-            queue.append((result, matched + 1, index + 1))
+            stack.append((result, matched + 1, index + 1))
 
         if not include_short:
             return
@@ -582,7 +582,7 @@ class StsDict():
                         match.conv.values.append(match_key)
                 for value in match.conv.values:
                     result = parts[:index] + [value] + parts[match.end:]
-                    queue.append((result, matched + 1, index + 1))
+                    stack.append((result, matched + 1, index + 1))
 
         # add atomic stepping (length = 1) case
         #
@@ -596,7 +596,7 @@ class StsDict():
         # Add ["采", "信", "息"] so that "采訊息" is not missed.
         #             ^
         if not has_atomic_match:
-            queue.append((parts, matched, index + 1))
+            stack.append((parts, matched, index + 1))
 
 class Table(StsDict):
     """A cache-boosted STS dictionary.
@@ -1169,7 +1169,7 @@ def main():
         help="""file(s) to convert (default: STDIN)""")
     parser_convert.add_argument('-c', '--config', default='s2t',
         help="""the config to use, either a built-in config name or a path to a custom JSON file
-(built-in configs: s2t|t2s|s2tw|tw2s|s2twp|tw2sp|s2hk|hk2s|t2tw|tw2t|t2twp|tw2tp|t2hk|hk2t|t2jp|jp2t)
+(built-in configs: s2t|t2s|s2tw|tw2s|s2twp|tw2sp|s2hk|hk2s|t2tw|tw2t|t2hk|hk2t|t2jp|jp2t)
 (default: %(default)s)""")
     parser_convert.add_argument('-f', '--format', default="txt",
         choices=['txt', 'txtm', 'html', 'htmlpage', 'json'], metavar='FORMAT',
